import type { Parser } from "@lezer/common";
import type { Node as ProseMirrorNode } from "prosemirror-model";
import { Decoration } from "prosemirror-view";
/**
 * Options to alter the behavior of getHighlightDecorations
 * @public
 */
interface GetHighlightDecorationsOptions {
    /**
     * A method that is called before the render process begins where any non-null return value cancels the render; useful for decoration caching on untouched nodes
     * @param block The node that is about to render
     * @param pos The position in the document of the node
     * @returns An array of the decorations that should be used instead of rendering; cancels the render if a non-null value is returned
     */
    preRenderer?: (block: ProseMirrorNode, pos: number) => Decoration[] | null;
    /**
     * A method that is called after the render process ends with the result of the node render passed; useful for decoration caching
     * @param block The node that was renderer
     * @param pos The position of the node in the document
     * @param decorations The decorations that were rendered for this node
     */
    postRenderer?: (block: ProseMirrorNode, pos: number, decorations: Decoration[]) => void;
}
/**
 * A collection of lezer parsers keyed by language id or `*` as a fallback
 * @public
 */
export declare type ParserCollection = Record<string | "*", Parser>;
/**
 * Gets all highlighting decorations from a ProseMirror document
 * @param doc The doc to search applicable blocks to highlight
 * @param parsers An object containing pre-configured lezer parsers keyed by language; supports "*" as a fallback
 * @param nodeTypes An array containing all the node types to target for highlighting
 * @param languageExtractor A method that is passed a prosemirror node and returns the language string to use when highlighting that node
 * @param options The options to alter the behavior of getHighlightDecorations
 * @public
 */
export declare function getHighlightDecorations(doc: ProseMirrorNode, parsers: ParserCollection, nodeTypes: string[], languageExtractor: (node: ProseMirrorNode) => string | null, options?: GetHighlightDecorationsOptions): Decoration[];
export {};
